summaryrefslogtreecommitdiff
path: root/src/reel_subtitle_asset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/reel_subtitle_asset.h')
-rw-r--r--src/reel_subtitle_asset.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/reel_subtitle_asset.h b/src/reel_subtitle_asset.h
index 91dcd53b..1d76ba9e 100644
--- a/src/reel_subtitle_asset.h
+++ b/src/reel_subtitle_asset.h
@@ -39,6 +39,7 @@
#define LIBDCP_REEL_SUBTITLE_ASSET_H
#include "reel_asset.h"
+#include "reel_mxf.h"
#include "subtitle_asset.h"
namespace dcp {
@@ -46,19 +47,22 @@ namespace dcp {
class SubtitleAsset;
/** @class ReelSubtitleAsset
* @brief Part of a Reel's description which refers to a subtitle XML file.
*/
-class ReelSubtitleAsset : public ReelAsset
+class ReelSubtitleAsset : public ReelAsset, public ReelMXF
{
public:
ReelSubtitleAsset (boost::shared_ptr<SubtitleAsset> asset, Fraction edit_rate, int64_t instrinsic_duration, int64_t entry_point);
explicit ReelSubtitleAsset (boost::shared_ptr<const cxml::Node>);
+ void write_to_cpl (xmlpp::Node* node, Standard standard) const;
+
boost::shared_ptr<SubtitleAsset> asset () const {
return asset_of_type<SubtitleAsset> ();
}
private:
+ std::string key_type () const;
std::string cpl_node_name () const;
};
@@ -46,19 +47,22 @@ namespace dcp {
class SubtitleAsset;
/** @class ReelSubtitleAsset
- * @brief Part of a Reel's description which refers to a subtitle XML file.
+ * @brief Part of a Reel's description which refers to a subtitle XML/MXF file.
*/